@@ -352,23 +352,25 @@ class GraphButton(Button):
             color = entry["color"]
             data = entry["data"]
 
+            print(f"### COLOR {color}, DATA {data}")
             def scale_y_value(value):
                 center_val = value - (range / 2)
                 return self.y + (self.h / 2 - (
                         (center_val - min_val) / range) * self.h)
 
-            prev_y = scale_y_value(data[0])
-            prev_x = graph_pos[0]
-            for val in data:
-                x = prev_x + 1
-                print(f"### SCALE {val}...")
-                y = scale_y_value(val)
-                print(f"### ... TO {y}")
-                pygame.draw.line(surface, color, (prev_x, prev_y), (x, y), 2)
-                prev_x = x
-                prev_y = y
+            # Need two data points to start the graph
+            if len(data) > 1:
+                prev_y = scale_y_value(data[0])
+                prev_x = graph_pos[0]
+                for val in data:
+                    x = prev_x + 1
+                    print(f"### SCALE {val}...")
+                    y = scale_y_value(val)
+                    print(f"### ... TO {y}")
+                    pygame.draw.line(surface, color, (prev_x, prev_y), (x, y), 2)
+                    prev_x = x
+                    prev_y = y
 
-            if len(data) > 0:
                 print(f"### RENDER LAST VALUE")
                 print(f"### OF {data[-1]}")
 
